@@ -1,3 +1,3 @@
 from .data_handler.creator import DataCreator
 from .data_handler.loader import DatasetSampler
-from .data_handler.img.augmentation import ImageTransformer
+from .data_handler.transform.augmentation import ImageTransformer
